Built in components

### Navigation

- index
- next |
- previous |
- fantastico 0.4.0-b114 documentation »
- Fantastico features »

# Built in components

Fantastico framework is really young and continuously improving. As of version 0.2.0 it is extremely easy to reuse components provided urls in other context. This feature opens the possibility to provide common day by day used components in new projects in order to accelerate development. In this document you can find a detailed list of built in components as well as sample of how to use them:

- Dynamic menu
  - Integration
  - Current limitations
  - Technical summary
- Dynamic pages
  - Integration
  - Current limitations
  - Technical summary
- Tracking codes
  - Analytic solutions
  - Integration
  - Current limitations
  - Technical summary